<?php

if (!function_exists('i18n_compare_search_results_score')) {
  function i18n_compare_search_results_score($a, $b) {
    if ($a['score'] == $b['score']) {
      $r = $b['date'] - $a['date'];
      return $r != 0 ? $r : strcmp($a['url'], $b['url']);
    } else {
      return $b['score'] - $a['score'];
    }
  }

  function i18n_compare_search_results_url($a, $b) {
    return strcmp($a['url'], $b['url']);
  }

  function i18n_compare_search_results_reverseurl($a, $b) {
    return strcmp($b['url'], $a['url']);
  }

  function i18n_compare_search_results_date($a, $b) {
    $r = $b['date'] - $a['date'];
    return $r != 0 ? $r : strcmp($a['url'], $b['url']);
  }

  function i18n_compare_search_results_created($a, $b) {
    $r = $b['created'] - $a['created'];
    return $r != 0 ? $r : strcmp($a['url'], $b['url']);
  }
}

  // parameters: $tags=null, $words=null, $order=null
  $results = array();
  if (!$tags && isset($_REQUEST['tags'])) $tags = trim($_REQUEST['tags']);
  if (!$words && isset($_REQUEST['words'])) $words = trim($_REQUEST['words']);
  if (!$tags && !$words) return $results;
  if ($tags && !is_array($tags)) $tags = trim($tags) != '' ? preg_split("/\s+/", trim($tags)) : array();
  if ($words && !is_array($words)) $words = trim($words) != '' ? preg_split("/\s+/", trim($words)) : array();
  if (count($tags) <= 0 && count($words) <= 0) return $results;
  if (!file_exists(GSDATAOTHERPATH . I18N_WORD_INDEX)) i18n_create_search_index();
  // use multibyte string functions?
  $ismb = function_exists('mb_ereg_replace');
  if ($ismb) mb_regex_encoding('UTF-8');
  // language?
  $defaultLanguage = function_exists('return_i18n_default_language') ? return_i18n_default_language() : '';
  $languages = function_exists('return_i18n_languages') ? return_i18n_languages() : array($defaultLanguage);
  $urlScores = null;
  if ($tags && count($tags) > 0) {
    $tagUrls = array();
    for ($i=0; $i<count($tags); $i++) {
      if ($ismb) {
        $tags[$i] = mb_ereg_replace("[^\w]", "_", mb_strtolower(trim($tags[$i]), 'UTF-8'));
      } else { 
        $tags[$i] = preg_replace("/[^\w]/", "_", strtolower(trim($tags[$i])));
      }
      $tagUrls[$tags[$i]] = array();
    }
    $f = fopen(GSDATAOTHERPATH . I18N_TAG_INDEX, "r");
    while (($line = fgets($f)) !== false) {
      foreach ($tags as $tag) {
        if (strncmp($line, $tag.' ', strlen($tag)+1) == 0) {
          $urls = preg_split("/\s+/", trim($line));
          unset($urls[0]);
          foreach ($urls as $url) {
            $tagUrls[$tag][$url] = 1;
          }
        }  
      }
    }
    fclose($f);
    foreach ($tags as $tag) {
      if ($urlScores === null) {
        $urlScores = $tagUrls[$tag]; 
      } else { 
        $urlScores = array_intersect_key($urlScores, $tagUrls[$tag]);
      }
    }
  }
  if ($words && count($words) > 0) {
    $wordUrls = array();
    for ($i=0; $i<count($words); $i++) {
      if ($ismb) {
        $words[$i] = mb_strtolower(trim($words[$i]), 'UTF-8');
      } else {
        $words[$i] = strtolower(trim($words[$i]));
      }
      $wordUrls[$words[$i]] = array();
    }
    $f = fopen(GSDATAOTHERPATH . I18N_WORD_INDEX, "r");
    while (($line = fgets($f)) !== false) {
      foreach ($words as $word) {
        if (i18n_is_word($line, $word, $ismb)) {
          $urls = preg_split("/\s+/", trim($line));
          unset($urls[0]);
          foreach ($urls as $url) {
            $pos = strpos($url,":");
            $score = (int) substr($url, $pos+1);
            $url = substr($url, 0, $pos);
            $pos = strpos($url,"_");
            $rawurl = $pos !== false ? substr($url, 0, $pos) : $url;
            if (isset($wordUrls[$word][$url])) {
              $wordUrls[$word][$url] += $score;
            } else if ($urlScores == null || isset($urlScores[$url])) {
              $wordUrls[$word][$url] = $score;
            }
          }
        }  
      }
    }
    fclose($f);
    foreach ($words as $word) {
      if ($urlScores === null) {
        $urlScores = $wordUrls[$word];
      } else {
        $urlScores = array_intersect_key($urlScores, $wordUrls[$word]);
        foreach ($urlScores as $url => $score) {
          $urlScores[$url] = $score * $wordUrls[$word][$url];
        }
      }
    }
  }
  if ($urlScores && count($urlScores) > 0) {
    $urlDates = array();
    $urlCreated = array();
    $f = fopen(GSDATAOTHERPATH . I18N_DATE_INDEX, "r");
    while (($line = fgets($f)) !== false) {
      $items = preg_split("/\s+/", trim($line));
      if (count($items) >= 2 && isset($urlScores[$items[0]])) {
        $urlDates[$items[0]] = (int) $items[1];
        $urlCreated[$items[0]] = count($items) >= 3 ? (int) $items[2] : (int) $items[1];
      }
    }
    fclose($f);
    foreach ($urlScores as $url => $score) {
      $pos = strpos($url,"_");
      $language = $pos !== false ? substr($url, $pos+1) : $defaultLanguage;
      if (in_array($language, $languages)) { // ignore language, if not default and not requested by user
        $rawurl = $pos !== false ? substr($url, 0, $pos) : $url;
        $results[] = array('url' => $rawurl, 'slug' => $url, 'score' => $score, 'date' => $urlDates[$url], 
                           'created' => $urlCreated[$url], 'language' => $language);
      }
    }
    switch ($order) {
      case 'url': usort($results, 'i18n_compare_search_results_url'); break;
      case 'reverseurl': usort($results, 'i18n_compare_search_results_reverseurl'); break;
      case 'date': usort($results, 'i18n_compare_search_results_date'); break;
      case 'created': usort($results, 'i18n_compare_search_results_created'); break;
      default: usort($results, 'i18n_compare_search_results_score');
    }
  }

