<?php
  $i18n = &$params; // alias for i18n parsing
  $is_i18n = function_exists('return_i18n_default_language');
  $tags = array_key_exists('tags',$params) ? $params['tags'] : (isset($_REQUEST['tags']) ? trim($_REQUEST['tags']) : null);
  $words = array_key_exists('words',$params) ? $params['words'] : (isset($_REQUEST['words']) ? trim($_REQUEST['words']) : null);
  $order = array_key_exists('order',$params) ? $params['order'] : null;
  if (!$tags && !$words && !isset($_REQUEST['tags']) && !isset($_REQUEST['words'])) return;
  $headerText = @$i18n['HEADER'];
  $notFoundText = @$i18n['NOT_FOUND'];
  $showLanguage = array_key_exists('showLanguage',$params) ? $params['showLanguage'] : $is_i18n;
  $showDate = array_key_exists('showDate',$params) ? $params['showDate'] : true;
  $dateLocale = @$i18n['DATE_LOCALE'];
  $dateFormat = @$i18n['DATE_FORMAT'];
  $numWords = array_key_exists('numWords',$params) ? (int) $params['numWords'] : I18N_NUM_WORDS;
  $max = array_key_exists('max',$params) ? (int) $params['max'] : I18N_MAX_RESULTS; 
  $showPaging = array_key_exists('showPaging',$params) ? $params['showPaging'] : true;

  $pageNum = isset($_REQUEST['page']) ? @((int) $_REQUEST['page']) - 1 : 0;
  $first = $pageNum * $max;
  $r = return_i18n_search_results($tags, $words, $first === null ? 0 : $first, $max, $numWords, $order);
  $results = $r['results'];
?>
  <h2><?php echo $headerText; ?></h2>
<?php
  if (count($results) <= 0) {
?>
<p class="search-no-results"><?php echo htmlspecialchars($notFoundText); ?></p>
<?php
  } else {
    $numpages = 1 + (int)(($r['totalCount']-1) / $max);
    $oldLocale = setlocale(LC_TIME,'0');
    if ($dateLocale) setlocale(LC_TIME, preg_split('/\s*,\s*/', $dateLocale));
?>
<ul class="search-results">
<?php
    foreach ($results as $result) {
      $pageUrl = find_url($result['url'], $result['parent']);
      if ($is_i18n) {
        $pageUrl .= (strpos($pageUrl,'?') !== false ? '&' : '?') . 'lang=' . urlencode($result['language']);
      }
?>
  <li class="search-entry">
    <h3 class="search-entry-title">
<?php if ($showLanguage) { ?>
      <span class="search-entry-language"><?php echo htmlspecialchars($result['language'], ENT_NOQUOTES); ?></span>
<?php } ?>
      <a href="<?php echo $pageUrl; ?>">
        <?php echo htmlspecialchars($result['title'], ENT_NOQUOTES); ?>
      </a>
    </h3>
<?php if ($showDate) { ?>
    <div class="search-entry-date"><?php echo strftime($dateFormat, $result['date']); ?></div>
<?php } ?>
<?php if ($numWords >= 0) { ?>
    <div class="search-entry-excerpt"><?php echo $result['excerpt']; ?></div>
<?php } else { ?>
    <div class="search-entry-content"><?php echo $result['content']; ?></div>
<?php } ?>
  </li>
<?php
    }
    if ($dateLocale) setLocale(LC_TIME, $oldLocale);
?>
</ul>
<?php
    if ($showPaging && $numpages > 1) {
      $pagingHtml = '';
      $pageUrl = get_page_url(true); 
      $pageUrl .= (strpos($pageUrl,'?') !== false ? '&' : '?');
      foreach ($_REQUEST as $name => $value) {
        if ($name != 'page' && $name != 'id' && $name != 'PHPSESSID') $pageUrl .= urlencode($name) . '=' . urlencode($value) . '&';
      }
      $pageUrl .= 'page=';
      $pagingHtml .= '<div class="paging">';
      if (@$i18n['FIRST_TEXT'] && $pageNum > 0) {
        $pagingHtml .= '<span class="first"><a href="'.$pageUrl.(1).'" title="'.htmlspecialchars(@$i18n['FIRST_TITLE']).'">'.htmlspecialchars(@$i18n['FIRST_TEXT']).'&nbsp;</a></span>';
      }
      if (@$i18n['PREV_TEXT'] && $pageNum > 0) {
        $pagingHtml .= '<span class="previous"><a href="'.$pageUrl.($pageNum).'" title="'.htmlspecialchars(@$i18n['PREV_TITLE']).'">'.htmlspecialchars(@$i18n['PREV_TEXT']).'&nbsp;</a></span>';
      }
      for ($i=0; $i<$numpages; $i++) {
        if ($i == $pageNum) {
          $pagingHtml .= ' <span class="current">'.($i+1).'</span>';
        } else {
          $pagingHtml .= ' <span><a href="'.$pageUrl.($i+1).'">'.($i+1).'</a></span>';
        }
      }
      if (@$i18n['NEXT_TEXT'] && $pageNum < $numpages-1) {
        $pagingHtml .= ' <span class="next"><a href="'.$pageUrl.($pageNum+2).'" title="'.htmlspecialchars(@$i18n['NEXT_TITLE']).'">&nbsp;'.htmlspecialchars(@$i18n['NEXT_TEXT']).'</a></span>';
      }
      if (@$i18n['LAST_TEXT'] && $pageNum < $numpages-1) {
        $pagingHtml .= ' <span class="next"><a href="'.$pageUrl.($pageNum+2).'" title="'.htmlspecialchars(@$i18n['LAST_TITLE']).'">&nbsp;'.htmlspecialchars(@$i18n['LAST_TEXT']).'</a></span>';
      }
      $pagingHtml .= '</div>';
      echo "\n" . $pagingHtml;
    }
  }

